==> form-dinamico-react-render-0.7.0.tgz: package/es/components/FileGrid/FileGridItem.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';

import GridListTile from '@material-ui/core/GridListTile';
import GridListTileBar from '@material-ui/core/GridListTileBar';
import IconButton from '@material-ui/core/IconButton';

import DeleteIcon from '@material-ui/icons/Delete';

import FileImage from './FileImage';

function FileGridItem(_ref) {
    var file = _ref.file,
        onFileClick = _ref.onFileClick,
        onDeleteClick = _ref.onDeleteClick,
        index = _ref.index,
        props = _objectWithoutProperties(_ref, ['file', 'onFileClick', 'onDeleteClick', 'index']);

    var handleDelete = function handleDelete() {
        onDeleteClick && onDeleteClick(file, index);
    };

    var handleDownload = function handleDownload() {
        onFileClick && onFileClick(file);
    };

    return React.createElement(
        GridListTile,
        _extends({}, props, {
            style: _extends({}, props.style, {
                width: 'auto'
            })
        }),
        React.createElement(FileImage, {
            src: file.preview ? file.preview : file.link,
            alt: file.name,
            onClick: handleDownload,
            style: {
                height: '100%',
                cursor: 'pointer'
            }
        }),
        React.createElement(GridListTileBar, {
            title: file.name,
            subtitle: React.createElement(
                'span',
                null,
                file.length + ' bytes'
            ),
            actionIcon: React.createElement(
                IconButton,
                { onClick: handleDelete },
                React.createElement(DeleteIcon, { color: 'disabled' })
            )
        })
    );
}

FileGridItem.muiName = 'GridListTile';

FileGridItem.defaultProps = {
    style: {}
};

FileGridItem.propTypes = process.env.NODE_ENV !== "production" ? {} : {};

export default FileGridItem;

==> form-dinamico-react-render-0.7.2.tgz: package/es/components/FileGrid/FileGridItem.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';

import { withStyles } from '@material-ui/core/styles/index';

import GridListTile from '@material-ui/core/GridListTile';
import GridListTileBar from '@material-ui/core/GridListTileBar';
import IconButton from '@material-ui/core/IconButton';

import DeleteIcon from '@material-ui/icons/Delete';

import FileImage from './FileImage';

var styles = {
    deleteIcon: {
        color: '#fff'
    }
};

function FileGridItem(_ref) {
    var classes = _ref.classes,
        file = _ref.file,
        onFileClick = _ref.onFileClick,
        onDeleteClick = _ref.onDeleteClick,
        index = _ref.index,
        props = _objectWithoutProperties(_ref, ['classes', 'file', 'onFileClick', 'onDeleteClick', 'index']);

    var handleDelete = function handleDelete() {
        onDeleteClick && onDeleteClick(file, index);
    };

    var handleDownload = function handleDownload() {
        onFileClick && onFileClick(file);
    };

    return React.createElement(
        GridListTile,
        _extends({}, props, {
            style: _extends({}, props.style, {
                width: 'auto'
            })
        }),
        React.createElement(FileImage, {
            src: file.preview ? file.preview : file.link,
            alt: file.name,
            onClick: handleDownload,
            style: {
                height: '100%',
                cursor: 'pointer'
            }
        }),
        React.createElement(GridListTileBar, {
            title: file.name,
            subtitle: React.createElement(
                'span',
                null,
                file.length + ' bytes'
            ),
            actionIcon: React.createElement(
                IconButton,
                { onClick: handleDelete },
                React.createElement(DeleteIcon, {
                    classes: {
                        root: classes.deleteIcon
                    }
                })
            )
        })
    );
}

FileGridItem.muiName = 'GridListTile';

FileGridItem.defaultProps = {
    style: {}
};

FileGridItem.propTypes = process.env.NODE_ENV !== "production" ? {} : {};

export default withStyles(styles)(FileGridItem);
